import httpclient from '../common/httpclient'
import urlbuilder from '../common/urlbuilder'

export default {
  // LIFE-CYCLE CALLBACKS:

  // onLoad () {},

  // start () {},

  // update (dt) {},

  init(channelid, gameid, isoffical, owner, url) {
    this.owner = owner;
    this.gameid = gameid;
    this.channelid = channelid;
    this.urlbd = new urlbuilder(url);
    //console.log("[jcshare]init:"+gameid + "|" + channelid + "|" + isoffical);
  },

  setAccountID(accountid, sessionid) {
    this.accountid = accountid;
    this.sessionid = sessionid;
  },

  setNickName(nickname) {
    this.nickname = nickname;
  },

  setFromAppID(appid) {
    this.fromid = appid;
  },

  setLocalUUID(uuid) {
    this.localid = uuid;
  },

  setSystemInfo(info) {

  },

  setUserInfo(info) {
    this.sex = info.sex;
    this.avatar_url = info.avatar_url;
  },

  /**
   * 接受邀请（分级时用，大部分时候不用此接口）
   * @param {string} actionid  业务号
   * @param {string} inviterid  邀请方账号id
   * @param {object} successcb  成功回调（以下该名称都是此功能）
   * @param {object} failcb 失败回调（以下该名称都是此功能）
   */
  acceptInvite(actionid, inviterid, successcb, failcb) {
    if (!actionid) {
      return;
    }
    let sid = inviterid ? inviterid : '';
    this.urlbd.clear();
    this.urlbd.addKV('c', 'Fission')
      .addKV('a', 'accept')
      .addKV('session_id', this.sessionid)
      .addKV('account_id', this.accountid)
      .addKV('business_no', actionid)
      .addKV('inviter_id', sid)
      .addKV('nickname', this.nickname)
      .addKV('sex', this.sex)
      .addKV('avatar_url', this.avatar_url)
      ;

    httpclient.httpGet(this.urlbd.baseurl, function (restext) {
      var obj = JSON.parse(restext);
      if (obj.errcode == 0 || obj.errcode == 1 || obj.errcode == 2) {
        //console.log('[acceptInvite]success!'+JSON.stringify(obj));
        successcb && successcb();
      } else {
        //console.log('[acceptInvite]failed!'+obj.errcode+":"+obj.errmsg);
        failcb && failcb(0, obj.errcode, obj.errmsg);
      }
    }, function (errcode, errmsg) {
      //console.log('[acceptInvite]failed!'+errcode+":"+errmsg);
      failcb && failcb(errcode, 0, errmsg);
    });
  },

  /**
   * 查询子节点数据（分级时用，大部分时候不用此接口）
   * @param {string} actionid 业务号
   * @param {object} successcb
   * @param {object} failcb
   */
  queryShareStat(actionid, successcb, failcb) {
    this.urlbd.clear();
    this.urlbd.addKV('c', 'Fission')
      .addKV('a', 'getChild')
      .addKV('session_id', this.sessionid)
      .addKV('account_id', this.accountid)
      .addKV('business_no', actionid);

    httpclient.httpGet(this.urlbd.baseurl, function (restext) {
      var obj = JSON.parse(restext);
      if (obj.errcode == 0) {
        //console.log('[queryShareStat]success!'+JSON.stringify(obj));
        successcb && successcb(obj.nodes);
      } else {
        //console.log('[queryShareStat]failed!'+obj.errcode+":"+obj.errmsg);
        failcb && failcb(0, obj.errcode, obj.errmsg);
      }
    }, function (errcode, errmsg) {
      //console.log('[queryShareStat]failed!'+errcode+":"+errmsg);
      failcb && failcb(errcode, 0, errmsg);
    });
  },

  /**
   * 查询接受邀请人的详细信息（分级时用，大部分时候不用此接口）
   * @param {string} actionid 业务号
   * @param {object} successcb
   * @param {object} failcb
   */
  queryShareDetail(actionid, successcb, failcb) {
    this.urlbd.clear();
    this.urlbd.addKV('c', 'Fission')
      .addKV('a', 'getFriendsDetail')
      .addKV('session_id', this.sessionid)
      .addKV('account_id', this.accountid)
      .addKV('business_no', actionid);

    httpclient.httpGet(this.urlbd.baseurl, function (restext) {
      var obj = JSON.parse(restext);
      if (obj.errcode == 0) {
        //console.log('[queryShareDetail]success!'+JSON.stringify(obj));
        successcb && successcb(obj.nodes);
      } else {
        //console.log('[queryShareDetail]failed!'+obj.errcode+":"+obj.errmsg);
        failcb && failcb(0, obj.errcode, obj.errmsg);
      }
    }, function (errcode, errmsg) {
      //console.log('[queryShareDetail]failed!'+errcode+":"+errmsg);
      failcb && failcb(errcode, 0, errmsg);
    });
  },

  /**
   * 每日任务的接受邀请【使用jcfw的话无需主动调用】
   * @param {string} actionid 任务id
   * @param {string} inviterid 邀请方账号id
   * @param {object} successcb
   * @param {object} failcb
   */
  acceptDailyInvite(actionid, inviterid, successcb, failcb) {
    let sid = inviterid ? inviterid : '';
    this.urlbd.clear();
    this.urlbd.addKV('c', 'DailyMission')
      .addKV('a', 'acceptInvite')
      .addKV('session_id', this.sessionid)
      .addKV('account_id', this.accountid)
      .addKV('inviter_id', sid)
      .addKV('activity_param', actionid)
      .addKV('nickname', this.nickname)
      .addKV('sex', this.sex)
      .addKV('avatar_url', this.avatar_url)
      ;

    httpclient.httpGet(this.urlbd.baseurl, function (restext) {
      var obj = JSON.parse(restext);
      if (obj.errcode == 0 || obj.errcode == 1) {
        //console.log('[acceptDailyInvite]success!'+JSON.stringify(obj));
        successcb && successcb();
      } else {
        //console.log('[acceptDailyInvite]failed!'+obj.errcode+":"+obj.errmsg);
        failcb && failcb(0, obj.errcode, obj.errmsg);
      }
    }, function (errcode, errmsg) {
      //console.log('[acceptDailyInvite]failed!'+errcode+":"+errmsg);
      failcb && failcb(errcode, 0, errmsg);
    });
  },

  /**
   * 每日任务的查询接受邀请的人数
   * @param {string} actionid 业务号
   * @param {object} successcb
   * @param {object} failcb
   */
  queryDailyShareStat(actionid, successcb, failcb) {
    this.urlbd.clear();
    this.urlbd.addKV('c', 'DailyMission')
      .addKV('a', 'getInviteeNum')
      .addKV('session_id', this.sessionid)
      .addKV('account_id', this.accountid)
      .addKV('activity_param', actionid);

    httpclient.httpGet(this.urlbd.baseurl, function (restext) {
      var obj = JSON.parse(restext);
      if (obj.errcode == 0) {
        //console.log('[queryDailyShareStat]success!'+JSON.stringify(obj));
        successcb && successcb(obj);
      } else {
        //console.log('[queryDailyShareStat]failed!'+obj.errcode+":"+obj.errmsg);
        failcb && failcb(0, obj.errcode, obj.errmsg);
      }
    }, function (errcode, errmsg) {
      //console.log('[queryDailyShareStat]failed!'+errcode+":"+errmsg);
      failcb && failcb(errcode, 0, errmsg);
    });
  },

  /**
   * 每日任务的查询接受邀请人的详细信息
   * @param {string} actionid 业务号
   * @param {object} successcb
   * @param {object} failcb
   */
  queryDailyShareDetail(actionid, successcb, failcb) {
    this.urlbd.clear();
    this.urlbd.addKV('c', 'DailyMission')
      .addKV('a', 'getInviteeList')
      .addKV('session_id', this.sessionid)
      .addKV('account_id', this.accountid)
      .addKV('activity_param', actionid);

    httpclient.httpGet(this.urlbd.baseurl, function (restext) {
      var obj = JSON.parse(restext);
      if (obj.errcode == 0) {
        //console.log('[queryDailyShareDetail]success!'+JSON.stringify(obj));
        successcb && successcb(obj.invitee_list);
      } else {
        //console.log('[queryDailyShareDetail]failed!'+obj.errcode+":"+obj.errmsg);
        failcb && failcb(0, obj.errcode, obj.errmsg);
      }
    }, function (errcode, errmsg) {
      //console.log('[queryDailyShareDetail]failed!'+errcode+":"+errmsg);
      failcb && failcb(errcode, 0, errmsg);
    });
  },

  /**
   * 上报游戏分数，获取兑换码
   * @param {string} score 分数
   * @param {object} successcb
   * @param {object} failcb
   */
  queryActionCode(score, successcb, failcb) {
    this.urlbd.clear();
    this.urlbd.addKV('c', 'Exchange')
      .addKV('a', 'reportScore')
      .addKV('session_id', this.sessionid)
      .addKV('account_id', this.accountid)
      .addKV('score', score);

    httpclient.httpGet(this.urlbd.baseurl, function (restext) {
      var obj = JSON.parse(restext);
      if (obj.errcode == 0) {
        //console.log('[queryActionCode]success!'+JSON.stringify(obj));
        successcb && successcb(obj.exchange_code);
      } else {
        //console.log('[queryActionCode]failed!'+obj.errcode+":"+obj.errmsg);
        failcb && failcb(0, obj.errcode, obj.errmsg);
      }
    }, function (errcode, errmsg) {
      //console.log('[queryActionCode]failed!'+errcode+":"+errmsg);
      failcb && failcb(errcode, 0, errmsg);
    });
  },

  /**
   * 接力活动的接受邀请
   * @param {string} actionid 任务id
   * @param {string} inviterid 邀请方账号id
   * @param {object} successcb
   * @param {object} failcb
   */
  acceptRelayInvite(actionid, inviterid, successcb, failcb) {
    let sid = inviterid ? inviterid : '';
    this.urlbd.clear();
    this.urlbd.addKV('c', 'Relay')
      .addKV('a', 'acceptInvite')
      .addKV('session_id', this.sessionid)
      .addKV('account_id', this.accountid)
      .addKV('inviter_id', sid)
      .addKV('activity_param', actionid)
      .addKV('nickname', this.nickname)
      .addKV('sex', this.sex)
      .addKV('avatar_url', this.avatar_url)
      ;

    httpclient.httpGet(this.urlbd.baseurl, function (restext) {
      var obj = JSON.parse(restext);
      if (obj.errcode == 0 || obj.errcode == 1) {
        //console.log('[acceptRelayInvite]success!'+JSON.stringify(obj));
        successcb && successcb();
      } else {
        //console.log('[acceptRelayInvite]failed!'+obj.errcode+":"+obj.errmsg);
        failcb && failcb(0, obj.errcode, obj.errmsg);
      }
    }, function (errcode, errmsg) {
      //console.log('[acceptRelayInvite]failed!'+errcode+":"+errmsg);
      failcb && failcb(errcode, 0, errmsg);
    });
  },

  /**
   * 接力活动的查询接受邀请的人数
   * @param {string} actionid 业务号
   * @param {object} successcb
   * @param {object} failcb
   */
  queryRelayShareStat(actionid, successcb, failcb) {
    this.urlbd.clear();
    this.urlbd.addKV('c', 'Relay')
      .addKV('a', 'getInviteeNum')
      .addKV('session_id', this.sessionid)
      .addKV('account_id', this.accountid)
      .addKV('activity_param', actionid);

    httpclient.httpGet(this.urlbd.baseurl, function (restext) {
      var obj = JSON.parse(restext);
      if (obj.errcode == 0) {
        //console.log('[queryRelayShareStat]success!'+JSON.stringify(obj));
        successcb && successcb(obj);
      } else {
        //console.log('[queryRelayShareStat]failed!'+obj.errcode+":"+obj.errmsg);
        failcb && failcb(0, obj.errcode, obj.errmsg);
      }
    }, function (errcode, errmsg) {
      //console.log('[queryRelayShareStat]failed!'+errcode+":"+errmsg);
      failcb && failcb(errcode, 0, errmsg);
    });
  },

  /**
   * 成就的接受邀请
   * @param {Array} relationidlst 有关联的成就id列表，格式如下：[[1001,3], [1002,3], [1003,3]]
   * @param {string} inviterid 邀请方账号id
   * @param {object} successcb
   * @param {object} failcb
   */
  acceptAchivementInvite(relationidlst, inviterid, successcb, failcb) {
    let sid = inviterid ? inviterid : '';
    this.urlbd.clear();
    this.urlbd.addKV('c', 'AchievementShare')
      .addKV('a', 'acceptInvite')
      .addKV('session_id', this.sessionid)
      .addKV('account_id', this.accountid)
      .addKV('inviter_id', sid)
      .addKV('relate_achivements', JSON.stringify(relationidlst))
      .addKV('nickname', this.nickname)
      .addKV('sex', this.sex)
      .addKV('avatar_url', this.avatar_url)
      ;

    httpclient.httpGet(this.urlbd.baseurl, function (restext) {
      var obj = JSON.parse(restext);
      if (obj.errcode == 0 || obj.errcode == 1) {
        //console.log('[acceptAchivementInvite]success!'+JSON.stringify(obj));
        successcb && successcb();
      } else {
        //console.log('[acceptAchivementInvite]failed!'+obj.errcode+":"+obj.errmsg);
        failcb && failcb(0, obj.errcode, obj.errmsg);
      }
    }, function (errcode, errmsg) {
      //console.log('[acceptAchivementInvite]failed!'+errcode+":"+errmsg);
      failcb && failcb(errcode, 0, errmsg);
    });
  },

  /**
   * 成就的查询接受邀请的人数
   * @param {Array} actionidlst  成就id列表，格式如下：[1001,1002,1003]
   * @param {object} successcb
   * @param {object} failcb
   */
  queryAchievementShareStat(actionidlst, successcb, failcb) {
    this.urlbd.clear();
    this.urlbd.addKV('c', 'AchievementShare')
      .addKV('a', 'getInviteeNum')
      .addKV('session_id', this.sessionid)
      .addKV('account_id', this.accountid)
      .addKV('achievement_ids', actionidlst.join());

    httpclient.httpGet(this.urlbd.baseurl, function (restext) {
      var obj = JSON.parse(restext);
      if (obj.errcode == 0) {
        //console.log('[queryAchievementShareStat]success!'+JSON.stringify(obj));
        successcb && successcb(obj);
      } else {
        //console.log('[queryAchievementShareStat]failed!'+obj.errcode+":"+obj.errmsg);
        failcb && failcb(0, obj.errcode, obj.errmsg);
      }
    }, function (errcode, errmsg) {
      //console.log('[queryAchievementShareStat]failed!'+errcode+":"+errmsg);
      failcb && failcb(errcode, 0, errmsg);
    });
  },

  /**
   * 成就的查询接受邀请的详细信息
   * @param {Array} actionidlst  成就id列表，格式如下：[1001,1002,1003]
   * @param {object} successcb
   * @param {object} failcb
   */
  queryAchievementShareDetail(actionidlst, successcb, failcb) {
    this.urlbd.clear();
    this.urlbd.addKV('c', 'AchievementShare')
      .addKV('a', 'getInviteeList')
      .addKV('session_id', this.sessionid)
      .addKV('account_id', this.accountid)
      .addKV('achievement_ids', actionidlst.join());

    httpclient.httpGet(this.urlbd.baseurl, function (restext) {
      var obj = JSON.parse(restext);
      if (obj && obj.errcode == 0) {
        //console.log('[queryAchievementShareDetail]success!'+JSON.stringify(obj));
        successcb && successcb(obj.invitee_list);
      } else {
        //console.log('[queryAchievementShareDetail]failed!'+obj.errcode+":"+obj.errmsg);
        failcb && failcb(0, obj.errcode, obj.errmsg);
      }
    }, function (errcode, errmsg) {
      //console.log('[queryAchievementShareDetail]failed!'+errcode+":"+errmsg);
      failcb && failcb(errcode, 0, errmsg);
    });
  },

  /**
   * 普通分享
   * @param {string} content 分享显示的标题
   * @param {string} imgurl 分享显示的图片
   * @param {int} sharetype 分享类型（每日活动/成就/接力）
   * @param {string} shareparam 分享类型相关参数（活动id/成就id等）
   * @param {string} extrainfo 分享额外参数（key/value格式的字符串：eg: 'inviter_name=***&inviter_sex=***'
   * @param {object} successcb
   * @param {object} failcb
   */
  shareNormal(content, imgurl, sharetype, shareparam, extrainfo, successcb, failcb) {
    let uuid = this.owner ? this.owner.makeUUID() : '';
    let qstr = 'inviter_id=' + this.accountid + '&activity_param='
      + shareparam + '&localuuid=' + uuid + '&sharetype=' + sharetype;
    if (extrainfo) {
      qstr += '&';
      qstr += extrainfo;
    }

    switch (this.channelid) {
      case 6001: {
        wx.shareAppMessage({
          title: content,
          imageUrl: imgurl,
          query: qstr
        });
        this.owner && this.owner.gamelog.logShare(sharetype, uuid, shareparam);
        successcb && successcb();
      }
        break;
      case 6002: {

      }
        break;
    }
  }
  ,


  shareCapture(content, rc, sharetype, shareparam, extrainfo, successcb, failcb) {
    let uuid = this.owner ? this.owner.makeUUID() : '';
    let qstr = 'inviter_id=' + this.accountid + '&activity_param='
      + shareparam + '&localuuid=' + uuid + '&sharetype=' + sharetype;
    if (extrainfo) {
      qstr += '&';
      qstr += extrainfo;
    }
    switch (this.channelid) {
      case 6001: {
        let surl = canvas.toTempFilePathSync({
          x: rc.x,
          y: rc.y,
          width: rc.width,
          height: rc.height,
          destWidth: 500,
          destHeight: 400
        });

        wx.shareAppMessage({
          title: content,
          imageUrl: surl,
          query: qstr
        });
        this.owner && this.owner.gamelog.logShare(sharetype, uuid, shareparam);
        successcb && successcb();
      }
        break;
      case 6002: {

      }
        break;
    }
  },

  acceptAchievementInvite(inviter_id, achievement_id, relate_achivements) {
    this.urlbd.clear();
    this.urlbd.addKV('c', 'AchievementShare')
      .addKV('a', 'acceptInvite')
      .addKV('account_id', this.accountid)
      .addKV('session_id', this.sessionid)
      .addKV('inviter_id', inviter_id);
    if (relate_achivements) {
      this.urlbd.addKV('relate_achivements', relate_achivements);
    } else {
      this.urlbd.addKV('achievement_id', Number(achievement_id));
    }
    //console.log(this.urlbd.baseurl);
    httpclient.httpGet(this.urlbd.baseurl, function (restext) {
      var obj = JSON.parse(restext);
      if (obj.errcode == 0) {
        //console.log('[acceptAchievementInvite]success!'+JSON.stringify(obj));
      } else {
        //console.log('[acceptAchievementInvite]failed!'+obj.errcode+":"+obj.errmsg);
      }
    }, function (errcode, errmsg) {
      //console.log('[acceptAchievementInvite]failed!'+errcode+":"+errmsg);
    });
  },
  getAchievInviteeNum(successcb, failcb) {
    this.urlbd.clear();
    this.urlbd.addKV('c', 'AchievementShare')
      .addKV('a', 'getInviteeNum')
      .addKV('account_id', this.accountid)
      .addKV('session_id', this.sessionid);
    // .addKV('achievement_ids', achievement_ids)
    httpclient.httpGet(this.urlbd.baseurl, function (restext) {
      var obj = JSON.parse(restext);
      if (obj.errcode == 0) {
        //console.log('[getAchievInviteeNum]success!'+JSON.stringify(obj));
        successcb && successcb(obj.invitee_nums);
      } else {
        //console.log('[getAchievInviteeNum]failed!'+obj.errcode+":"+obj.errmsg);
        failcb && failcb(0, obj.errcode, obj.errmsg);
      }
    }, function (errcode, errmsg) {
      //console.log('[getAchievInviteeNum]failed!'+errcode+":"+errmsg);
      failcb && failcb(errcode, 0, errmsg);
    });

  }

}
